@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Laurent Montel <montel@kde.org>
+   Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -128,7 +128,7 @@ void GravatarCache::clearAllCache()
         QDir dir(path);
         if (dir.exists()) {
             const QFileInfoList list = dir.entryInfoList();  // get list of matching files and delete all
-            Q_FOREACH (const QFileInfo &it, list) {
+            for (const QFileInfo &it : list) {
                 dir.remove(it.fileName());
             }
         }
