@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Laurent Montel <montel@kde.org>
+   Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -51,11 +51,6 @@ GravatarConfigureSettingsDialog::GravatarConfigureSettingsDialog(QWidget *parent
     mUseDefaultPixmap->setObjectName(QStringLiteral("usedefaultimage"));
     topLayout->addWidget(mUseDefaultPixmap);
 
-#if 0
-    mUseHttps = new QCheckBox(i18n("Use HTTPS"), this);
-    mUseHttps->setObjectName(QStringLiteral("usehttps"));
-    topLayout->addWidget(mUseHttps);
-#endif
     mUseLibravatar = new QCheckBox(i18n("Use Libravatar"), this);
     mUseLibravatar->setObjectName(QStringLiteral("uselibravatarcheckbox"));
     topLayout->addWidget(mUseLibravatar);
